cansig.metaanalysis package
===========================

Submodules
----------

cansig.metaanalysis.heatmap module
----------------------------------

.. automodule:: cansig.metaanalysis.heatmap
   :members:
   :undoc-members:
   :show-inheritance:

cansig.metaanalysis.repr_directory module
-----------------------------------------

.. automodule:: cansig.metaanalysis.repr_directory
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: cansig.metaanalysis
   :members:
   :undoc-members:
   :show-inheritance:
